from . import generic

def find_boundary_cells(data_container_array, feature_ids_array_path = None, boundary_cells_array_name = None, ignore_feature_zero = None, include_volume_boundary = None, observer = None) -> int:
  """
  FindBoundaryCells

  :param data_container_array | DataContainerArray
  :param feature_ids_array_path | DataArrayPath FeatureIdsArrayPath
  :param boundary_cells_array_name | QString BoundaryCellsArrayName
  :param ignore_feature_zero | bool IgnoreFeatureZero
  :param include_volume_boundary | bool IncludeVolumeBoundary
  :param observer | Observer
  """

  filter = generic.FindBoundaryCells()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if boundary_cells_array_name is not None:
    filter.BoundaryCellsArrayName = boundary_cells_array_name
  if ignore_feature_zero is not None:
    filter.IgnoreFeatureZero = ignore_feature_zero
  if include_volume_boundary is not None:
    filter.IncludeVolumeBoundary = include_volume_boundary
  filter.execute()
  return filter.ErrorCode

def find_bounding_box_features(data_container_array, calc_by_phase = None, centroids_array_path = None, phases_array_path = None, surface_features_array_path = None, biased_features_array_name = None, observer = None) -> int:
  """
  FindBoundingBoxFeatures

  :param data_container_array | DataContainerArray
  :param calc_by_phase | bool CalcByPhase
  :param centroids_array_path | DataArrayPath CentroidsArrayPath
  :param phases_array_path | DataArrayPath PhasesArrayPath
  :param surface_features_array_path | DataArrayPath SurfaceFeaturesArrayPath
  :param biased_features_array_name | QString BiasedFeaturesArrayName
  :param observer | Observer
  """

  filter = generic.FindBoundingBoxFeatures()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if calc_by_phase is not None:
    filter.CalcByPhase = calc_by_phase
  if centroids_array_path is not None:
    filter.CentroidsArrayPath = centroids_array_path
  if phases_array_path is not None:
    filter.PhasesArrayPath = phases_array_path
  if surface_features_array_path is not None:
    filter.SurfaceFeaturesArrayPath = surface_features_array_path
  if biased_features_array_name is not None:
    filter.BiasedFeaturesArrayName = biased_features_array_name
  filter.execute()
  return filter.ErrorCode

def find_feature_centroids(data_container_array, feature_ids_array_path = None, centroids_array_path = None, observer = None) -> int:
  """
  FindFeatureCentroids

  :param data_container_array | DataContainerArray
  :param feature_ids_array_path | DataArrayPath FeatureIdsArrayPath
  :param centroids_array_path | DataArrayPath CentroidsArrayPath
  :param observer | Observer
  """

  filter = generic.FindFeatureCentroids()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if centroids_array_path is not None:
    filter.CentroidsArrayPath = centroids_array_path
  filter.execute()
  return filter.ErrorCode

def find_feature_phases(data_container_array, feature_ids_array_path = None, cell_phases_array_path = None, feature_phases_array_path = None, observer = None) -> int:
  """
  FindFeaturePhases

  :param data_container_array | DataContainerArray
  :param feature_ids_array_path | DataArrayPath FeatureIdsArrayPath
  :param cell_phases_array_path | DataArrayPath CellPhasesArrayPath
  :param feature_phases_array_path | DataArrayPath FeaturePhasesArrayPath
  :param observer | Observer
  """

  filter = generic.FindFeaturePhases()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if feature_phases_array_path is not None:
    filter.FeaturePhasesArrayPath = feature_phases_array_path
  filter.execute()
  return filter.ErrorCode

def find_feature_phases_binary(data_container_array, feature_ids_array_path = None, good_voxels_array_path = None, feature_phases_array_path = None, cell_ensemble_attribute_matrix_name = None, observer = None) -> int:
  """
  FindFeaturePhasesBinary

  :param data_container_array | DataContainerArray
  :param feature_ids_array_path | DataArrayPath FeatureIdsArrayPath
  :param good_voxels_array_path | DataArrayPath GoodVoxelsArrayPath
  :param feature_phases_array_path | DataArrayPath FeaturePhasesArrayPath
  :param cell_ensemble_attribute_matrix_name | QString CellEnsembleAttributeMatrixName
  :param observer | Observer
  """

  filter = generic.FindFeaturePhasesBinary()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if good_voxels_array_path is not None:
    filter.GoodVoxelsArrayPath = good_voxels_array_path
  if feature_phases_array_path is not None:
    filter.FeaturePhasesArrayPath = feature_phases_array_path
  if cell_ensemble_attribute_matrix_name is not None:
    filter.CellEnsembleAttributeMatrixName = cell_ensemble_attribute_matrix_name
  filter.execute()
  return filter.ErrorCode

def find_surface_features(data_container_array, feature_ids_array_path = None, surface_features_array_path = None, observer = None) -> int:
  """
  FindSurfaceFeatures

  :param data_container_array | DataContainerArray
  :param feature_ids_array_path | DataArrayPath FeatureIdsArrayPath
  :param surface_features_array_path | DataArrayPath SurfaceFeaturesArrayPath
  :param observer | Observer
  """

  filter = generic.FindSurfaceFeatures()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if surface_features_array_path is not None:
    filter.SurfaceFeaturesArrayPath = surface_features_array_path
  filter.execute()
  return filter.ErrorCode

def generate_vector_colors(data_container_array, vectors_array_path = None, good_voxels_array_path = None, cell_vector_colors_array_name = None, use_good_voxels = None, observer = None) -> int:
  """
  GenerateVectorColors

  :param data_container_array | DataContainerArray
  :param vectors_array_path | DataArrayPath VectorsArrayPath
  :param good_voxels_array_path | DataArrayPath GoodVoxelsArrayPath
  :param cell_vector_colors_array_name | QString CellVectorColorsArrayName
  :param use_good_voxels | bool UseGoodVoxels
  :param observer | Observer
  """

  filter = generic.GenerateVectorColors()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if vectors_array_path is not None:
    filter.VectorsArrayPath = vectors_array_path
  if good_voxels_array_path is not None:
    filter.GoodVoxelsArrayPath = good_voxels_array_path
  if cell_vector_colors_array_name is not None:
    filter.CellVectorColorsArrayName = cell_vector_colors_array_name
  if use_good_voxels is not None:
    filter.UseGoodVoxels = use_good_voxels
  filter.execute()
  return filter.ErrorCode

